<?php

namespace Drupal\custom_configurations\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\custom_configurations\CustomConfigurationsManager;

/**
 * Class CustomConfigurationsController.
 *
 * @package Drupal\custom_configurations\Controller
 */
class CustomConfigurationsController extends ControllerBase {

  /**
   * Drupal\custom_configurations\CustomConfigurationsManager definition.
   *
   * @var \Drupal\custom_configurations\CustomConfigurationsManager
   */
  protected $customConfigurationsManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(CustomConfigurationsManager $custom_configurations_manager) {
    $this->customConfigurationsManager = $custom_configurations_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('custom_configurations.manager')
    );
  }

  /**
   * Returns index custom configurations plugin page.
   */
  public function getIndex() {

    $plugins = $this->customConfigurationsManager->getConfigPlugins();

    if (!empty($plugins)) {
      $links = [];
      foreach ($plugins as $plugin) {
        $route = 'custom_configurations.' . $plugin['id'] . '.form';
        $route_parameters = [
          'plugin_id' => $plugin['id']
        ];
        $url = Url::fromRoute($route, $route_parameters);
        $links[] = Link::fromTextAndUrl($plugin['title'], $url)->toString();
      }
      $build['list'] = [
        '#theme' => 'item_list',
        '#items' => $links,
      ];
    }
    else {
      $build = ['#markup' => t('No plugins found.')];
    }

    return $build;
  }

}
