<?php

namespace Drupal\custom_configurations\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Derivative class that provides the menu links for the Products.
 */
class CustomConfigurationsLinksDerivative extends DeriverBase implements ContainerDeriverInterface {

  /**
   * @var EntityTypeManagerInterface $entityTypeManager.
   */
  protected $entityTypeManager;

  /**
   * Creates a ProductMenuLink instance.
   *
   * @param $base_plugin_id
   * @param EntityTypeManagerInterface $entity_type_manager
   */
  public function __construct($base_plugin_id, EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $base_plugin_id,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $links = [];
    $plugins = \Drupal::service('custom_configurations.manager')->getConfigPlugins();
    foreach ($plugins as $plugin) {
      $links[] = [
        'title' => $plugin['title'],
        'route_name' => 'custom_configurations.' . $plugin['id'] . '.form',
        'weight' => $plugin['weight'],
        'route_parameters' => [
          'plugin_id' => $plugin['id']
        ]
      ] + $base_plugin_definition;
    }
    return $links;
  }
}
