<?php

/**
 * @file
 * Contains \Drupal\custom_configurations\Routing\CustomConfigurationsRoutes.
 */

namespace Drupal\custom_configurations\Routing;

use Drupal\Component\Utility\Html;
use Symfony\Component\Routing\Route;

/**
 * Defines dynamic routes.
 */
class CustomConfigurationsRoutes {

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $routes = array();
    $cc_manager = \Drupal::service('custom_configurations.manager');
    $plugins = $cc_manager->getConfigPlugins();

    /** @var \Drupal\Core\Language\LanguageManagerInterface $language_manager */
    $language_manager = \Drupal::languageManager();

    foreach ($plugins as $plugin) {

      $url_id = Html::getId($plugin['id']);

      $routes['custom_configurations.' . $plugin['id'] . '.form'] = new Route(
        '/admin/config/custom-configurations-' . $url_id . '/{plugin_id}/{language}',
        [
          '_form' => '\Drupal\custom_configurations\Form\CustomConfigurationsForm',
          '_title_callback' => '\Drupal\custom_configurations\Form\CustomConfigurationsForm::titleCallback',
          'plugin_id' => NULL,
          'language' => NULL
        ],
        ['_permission'  => 'access custom configurations'],
        ['_admin_route' => TRUE]
      );

      if ($cc_manager->languagesAvailable()) {
        $languages = $language_manager->getLanguages();
        foreach ($languages as $language_code => $lang) {

          $task_id = $plugin['id'] . '.' . $language_code;
          $url_id = Html::getId($plugin['id'] . '-' . $language_code);

          $routes['custom_configurations.' . $task_id . '.form'] = new Route(
            '/admin/config/custom-configurations-' . $url_id . '/{plugin_id}/{language}',
            [
              '_form' => '\Drupal\custom_configurations\Form\CustomConfigurationsForm',
              '_title_callback' => '\Drupal\custom_configurations\Form\CustomConfigurationsForm::titleCallback',
              'plugin_id' => NULL,
              'language' => NULL
            ],
            ['_permission'  => 'access custom configurations'],
            ['_admin_route' => TRUE]
          );
        }
      }

    }
    return $routes;
  }

}